<?php $pageTitle='Create a construct';
include realpath(__DIR__).'/../../core/_common/header.php'; ?>
<script type="text/javascript">

window.addEventListener('DOMContentLoaded',function(){
    const grid = ui.grid();
    const detailsBox = grid.box({
        classes: 'r1 c1 h3 w1',
        title: 'Details'
    });

    const frm = detailsBox.form({
        action: '/api/construct/',
        method: 'post',
    });
    frm.textField({ label:"Name", name:'name', value:'' });
	frm.textField({ label:"Description", name:'description', value:'' });
	frm.roleField({ 
		label:"Protein", 
		name:'proteinid', 
		otherType:'protein',
		//constraint:{ 'owner':userId },
		labelField:'name',
		headers:['Name','Project'],
		cellTemplates:['{{name}}','{{projectname}}']
	});
	frm.createButton();
	
});
</script>
<?php include realpath(__DIR__).'/../../core/_common/footer.php';
